#define MFBSOLIDFILLAREA xf1bppSolidBlackArea
#define MFBSTIPPLEFILLAREA xf1bppStippleBlackArea
#define OPEQ &=~
#define EQWHOLEWORD =0
#include "mfbmap.h"
#include "../../../mfb/mfbpntarea.c"
